@@ -1,7 +1,10 @@
 from typing import Optional
 
 from easypost.easypost_object import convert_to_easypost_object
-from easypost.requestor import Requestor
+from easypost.requestor import (
+    RequestMethod,
+    Requestor,
+)
 from easypost.resource import (
     AllResource,
     CreateResource,
@@ -14,5 +17,5 @@ class ScanForm(AllResource, CreateResource):
         """Create a scanform."""
         requestor = Requestor(local_api_key=api_key)
         url = cls.class_url()
-        response, api_key = requestor.request(method="post", url=url, params=params)
+        response, api_key = requestor.request(method=RequestMethod.POST, url=url, params=params)
         return convert_to_easypost_object(response=response, api_key=api_key)
