@@ -1,4 +1,7 @@
-from easypost.requestor import Requestor
+from easypost.requestor import (
+    RequestMethod,
+    Requestor,
+)
 from easypost.resource import (
     AllResource,
     CreateResource,
@@ -11,6 +14,6 @@ class Webhook(AllResource, CreateResource, DeleteResource):
         """Update a webhook."""
         requestor = Requestor(local_api_key=self._api_key)
         url = self.instance_url()
-        response, api_key = requestor.request(method="put", url=url, params=params)
+        response, api_key = requestor.request(method=RequestMethod.PUT, url=url, params=params)
         self.refresh_from(values=response, api_key=api_key)
         return self
